##  Step 3: Install the GitHub App
After creating a GitHub App and deploying the agent, the next step is to install the GitHub App on the relevant GitHub organizations. This grants the SAP LeanIX agent access to these organizations.
You can install the app in one of the following ways:
  * From the integration page in SAP LeanIX: Here, you can find a KPI indicating how many organizations are currently covered by the agent. To install the app on more organizations, click on the relevant link.
![Navigating to the GitHub App Installation Page from the GitHub Enterprise Integration Page](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c62937a441014943cedb641d25df4_LowRes.png)
Navigating to the GitHub App Installation Page from the GitHub Enterprise Integration Page
You're redirected to the installation page in GitHub.
![Installing a GitHub on an Account](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a707e7a441014a94fbab25bf79fcf_LowRes.png)
Installing a GitHub App on an Account
  * In the GitHub App settings: You can directly navigate to this page by going to https://{host url of your GitHub instance}/settings/apps/{name of the created GitHub app}. This will take you to the settings page of the GitHub App you created, where you can manage its installation across your organizations.
